@@ -17,15 +17,15 @@ import copy
 
 import netaddr
 
-from neutron.db import common_db_mixin
-from neutron_lib.api.definitions import constants as fw_const
 from neutron_lib import constants as nl_constants
 from neutron_lib.db import api as db_api
 from neutron_lib.db import constants as db_constants
 from neutron_lib.db import model_base
 from neutron_lib.db import model_query
+from neutron_lib.db import utils as db_utils
 from neutron_lib import exceptions
 from neutron_lib.exceptions import firewall_v2 as f_exc
+from oslo_config import cfg
 from oslo_db import exception as db_exc
 from oslo_log import log as logging
 from oslo_utils import uuidutils
@@ -180,7 +180,7 @@ def _list_firewall_policies_result_filter_hook(query, filters):
     return query
 
 
-class FirewallPluginDb(common_db_mixin.CommonDbMixin):
+class FirewallPluginDb(object):
 
     def __new__(cls, *args, **kwargs):
         model_query.register_hook(
@@ -200,19 +200,19 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
 
     def _get_firewall_group(self, context, id):
         try:
-            return self._get_by_id(context, FirewallGroup, id)
+            return model_query.get_by_id(context, FirewallGroup, id)
         except exc.NoResultFound:
             raise f_exc.FirewallGroupNotFound(firewall_id=id)
 
     def _get_firewall_policy(self, context, id):
         try:
-            return self._get_by_id(context, FirewallPolicy, id)
+            return model_query.get_by_id(context, FirewallPolicy, id)
         except exc.NoResultFound:
             raise f_exc.FirewallPolicyNotFound(firewall_policy_id=id)
 
     def _get_firewall_rule(self, context, id):
         try:
-            return self._get_by_id(context, FirewallRuleV2, id)
+            return model_query.get_by_id(context, FirewallRuleV2, id)
         except exc.NoResultFound:
             raise f_exc.FirewallRuleNotFound(firewall_rule_id=id)
 
@@ -289,7 +289,7 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
                'action': firewall_rule['action'],
                'enabled': firewall_rule['enabled'],
                'shared': firewall_rule['shared']}
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _make_firewall_policy_dict(self, firewall_policy, fields=None):
         fw_rules = [
@@ -302,7 +302,7 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
                'audited': firewall_policy['audited'],
                'firewall_rules': fw_rules,
                'shared': firewall_policy['shared']}
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _make_firewall_group_dict(self, firewall_group_db, fields=None):
         fwg_ports = [port_assoc.port_id for port_assoc in
@@ -319,7 +319,7 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
                'ports': fwg_ports,
                'status': firewall_group_db['status'],
                'shared': firewall_group_db['shared']}
-        return self._fields(res, fields)
+        return db_utils.resource_fields(res, fields)
 
     def _get_policy_ordered_rules(self, context, policy_id):
         query = (context.session.query(FirewallRuleV2)
@@ -409,39 +409,63 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
         # NOTE(xgerman) Maybe generating the final set of rules from a
         # configuration file makes sense. Can be done some time later
 
-        # 1. Drop any IPv4 packets for ingress traffic
+        # 1. Firewall rule for ingress IPv4 packets (DROP by default)
         in_fwr_v4 = {
             'description': 'default ingress rule for IPv4',
-            'name': 'default ingress ipv4 (deny all)',
-            'shared': False,
-            'protocol': None,
+            'name': 'default ingress ipv4',
+            'shared': cfg.CONF.default_fwg_rules.shared,
+            'protocol': cfg.CONF.default_fwg_rules.protocol,
             'tenant_id': tenant_id,
             'ip_version': nl_constants.IP_VERSION_4,
-            'action': fw_const.FWAAS_DENY,
-            'enabled': True,
-            'source_port': None,
-            'source_ip_address': None,
-            'destination_port': None,
-            'destination_ip_address': None,
+            'action': cfg.CONF.default_fwg_rules.ingress_action,
+            'enabled': cfg.CONF.default_fwg_rules.enabled,
+            'source_port': cfg.CONF.default_fwg_rules.ingress_source_port,
+            'source_ip_address':
+                cfg.CONF.default_fwg_rules.ingress_source_ipv4_address,
+            'destination_port':
+                cfg.CONF.default_fwg_rules.ingress_destination_port,
+            'destination_ip_address':
+                cfg.CONF.default_fwg_rules.
+                    ingress_destination_ipv4_address,
         }
 
-        # 2. Drop any IPv6 packets for ingress traffic
+        # 2. Firewall rule for ingress IPv6 packets (DROP by default)
         in_fwr_v6 = copy.deepcopy(in_fwr_v4)
         in_fwr_v6['description'] = 'default ingress rule for IPv6'
-        in_fwr_v6['name'] = 'default ingress ipv6 (deny all)'
+        in_fwr_v6['name'] = 'default ingress ipv6'
         in_fwr_v6['ip_version'] = nl_constants.IP_VERSION_6
+        in_fwr_v6['source_ip_address'] = \
+            cfg.CONF.default_fwg_rules.ingress_source_ipv6_address
+        in_fwr_v6['destination_ip_address'] = \
+            cfg.CONF.default_fwg_rules.ingress_destination_ipv6_address
 
-        # 3. Allow any IPv4 packets for egress traffic
+        # 3. Firewall rule for egress IPv4 packets (ALLOW by default)
         eg_fwr_v4 = copy.deepcopy(in_fwr_v4)
         eg_fwr_v4['description'] = 'default egress rule for IPv4'
-        eg_fwr_v4['action'] = fw_const.FWAAS_ALLOW
-        eg_fwr_v4['name'] = 'default egress ipv4 (allow all)'
+        eg_fwr_v4['name'] = 'default egress ipv4'
+        eg_fwr_v4['action'] = cfg.CONF.default_fwg_rules.egress_action
+        eg_fwr_v4['source_port'] = \
+            cfg.CONF.default_fwg_rules.egress_source_port
+        eg_fwr_v4['source_ip_address'] = \
+            cfg.CONF.default_fwg_rules.egress_source_ipv4_address
+        eg_fwr_v4['destination_port'] = \
+            cfg.CONF.default_fwg_rules.egress_destination_port
+        eg_fwr_v4['destination_ip_address'] = \
+            cfg.CONF.default_fwg_rules.egress_destination_ipv4_address
 
-        # 4. Allow any IPv6 packets for egress traffic
+        # 4. Firewall rule for egress IPv6 packets (ALLOW by default)
         eg_fwr_v6 = copy.deepcopy(in_fwr_v6)
         eg_fwr_v6['description'] = 'default egress rule for IPv6'
-        eg_fwr_v6['name'] = 'default egress ipv6 (allow all)'
-        eg_fwr_v6['action'] = fw_const.FWAAS_ALLOW
+        eg_fwr_v6['name'] = 'default egress ipv6'
+        eg_fwr_v6['action'] = cfg.CONF.default_fwg_rules.egress_action
+        eg_fwr_v6['source_port'] = \
+            cfg.CONF.default_fwg_rules.egress_source_port
+        eg_fwr_v6['source_ip_address'] = \
+            cfg.CONF.default_fwg_rules.egress_source_ipv6_address
+        eg_fwr_v6['destination_port'] = \
+            cfg.CONF.default_fwg_rules.egress_destination_port
+        eg_fwr_v6['destination_ip_address'] = \
+            cfg.CONF.default_fwg_rules.egress_destination_ipv6_address
 
         return {
             'in_ipv4': self.create_firewall_rule(context, in_fwr_v4)['id'],
@@ -569,9 +593,9 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
         return self._make_firewall_rule_dict(fwr, fields, policies=policies)
 
     def get_firewall_rules(self, context, filters=None, fields=None):
-        return self._get_collection(context, FirewallRuleV2,
-                                    self._make_firewall_rule_dict,
-                                    filters=filters, fields=fields)
+        return model_query.get_collection(
+            context, FirewallRuleV2, self._make_firewall_rule_dict,
+            filters=filters, fields=fields)
 
     def _get_rules_in_policy(self, context, fwpid):
         """Gets rules in a firewall policy"""
@@ -610,8 +634,8 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
 
     def _check_rules_for_policy_is_valid(self, context, fwp, fwp_db,
                                          rule_id_list, filters):
-        rules_in_fwr_db = self._get_collection_query(context, FirewallRuleV2,
-                                                 filters=filters)
+        rules_in_fwr_db = model_query.get_collection_query(
+            context, FirewallRuleV2, filters=filters)
         rules_dict = dict((fwr_db['id'], fwr_db) for fwr_db in rules_in_fwr_db)
         for fwrule_id in rule_id_list:
             if fwrule_id not in rules_dict:
@@ -706,7 +730,7 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
             # we need care about the associations related with this policy
             # and its rules only.
             filters['firewall_policy_id'] = [fwp_db['id']]
-            rules_in_fpol_rul_db = self._get_collection_query(
+            rules_in_fpol_rul_db = model_query.get_collection_query(
                 context,
                 FirewallPolicyRuleAssociation,
                 filters=filters)
@@ -791,9 +815,9 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
         return self._make_firewall_policy_dict(fwp, fields)
 
     def get_firewall_policies(self, context, filters=None, fields=None):
-        return self._get_collection(context, FirewallPolicy,
-                                    self._make_firewall_policy_dict,
-                                    filters=filters, fields=fields)
+        return model_query.get_collection(
+            context, FirewallPolicy, self._make_firewall_policy_dict,
+            filters=filters, fields=fields)
 
     def _set_ports_for_firewall_group(self, context, fwg_db, fwg):
         port_id_list = fwg['ports']
@@ -1068,9 +1092,9 @@ class FirewallPluginDb(common_db_mixin.CommonDbMixin):
             tenant_id = filters.get('tenant_id') if filters else None
             tenant_id = tenant_id[0] if tenant_id else context.tenant_id
             self._ensure_default_firewall_group(context, tenant_id)
-        return self._get_collection(context, FirewallGroup,
-                                    self._make_firewall_group_dict,
-                                    filters=filters, fields=fields)
+        return model_query.get_collection(
+            context, FirewallGroup, self._make_firewall_group_dict,
+            filters=filters, fields=fields)
 
 
 def _is_default(fwg_db):
