@@ -48,9 +48,44 @@ from neutron_fwaas.privileged import utils as fwaas_utils
 
 LOG = logging.getLogger(__name__)
 
-nfct = ctypes.CDLL(util.find_library('netfilter_conntrack'))
+nfct_lib = util.find_library('netfilter_conntrack')
+nfct = ctypes.CDLL(nfct_lib)
 libc = ctypes.CDLL(util.find_library('libc.so.6'))
 
+# In unit tests the actual nfct library may not be installed, and since we
+# don't make actual calls to it we don't want to add a hard dependency.
+if nfct_lib:
+    # It's important that the types be defined properly on all of the functions
+    # we call from nfct, otherwise pointers can be truncated and cause
+    # segfaults.
+    nfct.nfct_set_attr.argtypes = [ctypes.c_void_p,
+                                   ctypes.c_int,
+                                   ctypes.c_void_p]
+    nfct.nfct_set_attr_u8.argtypes = [ctypes.c_void_p,
+                                      ctypes.c_int,
+                                      ctypes.c_uint8]
+    nfct.nfct_set_attr_u16.argtypes = [ctypes.c_void_p,
+                                       ctypes.c_int,
+                                       ctypes.c_uint16]
+    nfct.nfct_snprintf.argtypes = [ctypes.c_char_p,
+                                   ctypes.c_uint,
+                                   ctypes.c_void_p,
+                                   ctypes.c_uint,
+                                   ctypes.c_uint,
+                                   ctypes.c_uint]
+    nfct.nfct_new.restype = ctypes.c_void_p
+    nfct.nfct_destroy.argtypes = [ctypes.c_void_p]
+    nfct.nfct_query.argtypes = [ctypes.c_void_p,
+                                ctypes.c_int,
+                                ctypes.c_void_p]
+    nfct.nfct_callback_register.argtypes = [ctypes.c_void_p,
+                                            ctypes.c_int,
+                                            ctypes.c_void_p,
+                                            ctypes.c_void_p]
+    nfct.nfct_open.restype = ctypes.c_void_p
+    nfct.nfct_close.argtypes = [ctypes.c_void_p]
+
+
 IP_VERSIONS = [constants.IP_VERSION_4, constants.IP_VERSION_6]
 DATA_CALLBACK = None
 
@@ -110,8 +145,9 @@ class ConntrackManager(object):
                       6: nfct.nfct_set_attr_u16},
             'dport': {4: nfct.nfct_set_attr_u16,
                       6: nfct.nfct_set_attr_u16}, }
-        self.converters = {'src': str,
-                      'dst': str,
+
+        self.converters = {'src': bytes,
+                      'dst': bytes,
                       'ipversion': nl_constants.IPVERSION_SOCKET.get,
                       'protocol': constants.IP_PROTOCOL_MAP.get,
                       'code': int,
@@ -130,7 +166,7 @@ class ConntrackManager(object):
                                conntrack, type_,
                                nl_constants.NFCT_O_PLAIN,
                                nl_constants.NFCT_OF_TIME)
-            entries.append(raw_entry.value)
+            entries.append(raw_entry.value.decode('utf-8'))
             return nl_constants.NFCT_CB_CONTINUE
 
         self._callback_register(nl_constants.NFCT_T_ALL,
@@ -169,7 +205,7 @@ class ConntrackManager(object):
         dest = ctypes.create_string_buffer(
             nl_constants.IPVERSION_BUFFER[addr_family])
         libc.inet_pton(nl_constants.IPVERSION_SOCKET[addr_family],
-                       source, dest)
+                       source.encode('utf-8'), dest)
         return dest.raw
 
     def _set_attributes(self, conntrack, entry):
