@@ -142,8 +142,8 @@ class FWaaSL3AgentExtension(l3_extension.L3AgentExtension):
 
     def _get_firewall_group_ports(self, context, firewall_group,
             to_delete=False, require_new_plugin=False):
-        """Returns in-namespace ports, either from firewall group dict if newer
-           version of plugin or from project routers otherwise.
+        """Returns in-namespace ports, either from firewall group dict if ports
+           update or from project routers otherwise if only policies update.
 
            NOTE: Vernacular move from "tenant" to "project" doesn't yet appear
            as a key in router or firewall group objects.
@@ -154,7 +154,7 @@ class FWaaSL3AgentExtension(l3_extension.L3AgentExtension):
                 fwg_port_ids = firewall_group['del-port-ids']
             else:
                 fwg_port_ids = firewall_group['add-port-ids']
-        elif not require_new_plugin:
+        if not require_new_plugin and not fwg_port_ids:
             routers = self.agent_api.get_routers_in_project(
                     firewall_group['tenant_id'])
             for router in routers:
@@ -271,6 +271,9 @@ class FWaaSL3AgentExtension(l3_extension.L3AgentExtension):
             ports_to_process = (set(firewall_group['add-port-ids'] +
                                     firewall_group['del-port-ids']) &
                                 all_router_ports)
+            # ensure no port in router is associated with the firewall group
+            if not ports_to_process:
+                continue
             # A port can have at most one firewall group.
             port_ids_to_exclude = ports_to_process & processed_ports
             if port_ids_to_exclude:
@@ -297,8 +300,8 @@ class FWaaSL3AgentExtension(l3_extension.L3AgentExtension):
             self.services_sync_needed = True
 
     def update_router(self, context, updated_router):
-        """Handles agent restart and router add. Fetches firewall groups from
-        plugin and updates driver.
+        """Handles agent restart and router update. Fetches firewall groups
+        from plugin and updates driver.
         """
         if not self.fwaas_enabled:
             return
@@ -473,7 +476,8 @@ class FWaaSL3AgentExtension(l3_extension.L3AgentExtension):
                            "for firewall group: %s")
                     LOG.exception(msg, firewall_group['id'])
                     status = nl_constants.ERROR
-            else:
+            elif not status:
+                # if status not set by now, set it to INACTIVE
                 status = nl_constants.INACTIVE
 
         # Return status to plugin.
